@@ -51,6 +51,11 @@ int handle__pubackcomp(struct mosquitto *mosq, const char *type)
 	if(mosquitto__get_state(mosq) != mosq_cs_active){
 		return MOSQ_ERR_PROTOCOL;
 	}
+	if(mosq->protocol != mosq_p_mqtt31){
+		if((mosq->in_packet.command&0x0F) != 0x00){
+			return MOSQ_ERR_MALFORMED_PACKET;
+		}
+	}
 
 	pthread_mutex_lock(&mosq->msgs_out.mutex);
 	util__increment_send_quota(mosq);
@@ -58,17 +63,59 @@ int handle__pubackcomp(struct mosquitto *mosq, const char *type)
 
 	rc = packet__read_uint16(&mosq->in_packet, &mid);
 	if(rc) return rc;
-	qos = type[3] == 'A'?1:2; /* pubAck or pubComp */
-	if(mid == 0) return MOSQ_ERR_PROTOCOL;
+	if(type[3] == 'A'){ /* pubAck or pubComp */
+		if(mosq->in_packet.command != CMD_PUBACK){
+			return MOSQ_ERR_MALFORMED_PACKET;
+		}
+		qos = 1;
+	}else{
+		if(mosq->in_packet.command != CMD_PUBCOMP){
+			return MOSQ_ERR_MALFORMED_PACKET;
+		}
+		qos = 2;
+	}
+	if(mid == 0){
+		return MOSQ_ERR_PROTOCOL;
+	}
 
 	if(mosq->protocol == mosq_p_mqtt5 && mosq->in_packet.remaining_length > 2){
 		rc = packet__read_byte(&mosq->in_packet, &reason_code);
-		if(rc) return rc;
+		if(rc){
+			return rc;
+		}
 
 		if(mosq->in_packet.remaining_length > 3){
 			rc = property__read_all(CMD_PUBACK, &mosq->in_packet, &properties);
 			if(rc) return rc;
 		}
+		if(type[3] == 'A'){ /* pubAck or pubComp */
+			if(reason_code != MQTT_RC_SUCCESS
+					&& reason_code != MQTT_RC_NO_MATCHING_SUBSCRIBERS
+					&& reason_code != MQTT_RC_UNSPECIFIED
+					&& reason_code != MQTT_RC_IMPLEMENTATION_SPECIFIC
+					&& reason_code != MQTT_RC_NOT_AUTHORIZED
+					&& reason_code != MQTT_RC_TOPIC_NAME_INVALID
+					&& reason_code != MQTT_RC_PACKET_ID_IN_USE
+					&& reason_code != MQTT_RC_QUOTA_EXCEEDED
+					&& reason_code != MQTT_RC_PAYLOAD_FORMAT_INVALID
+					){
+
+				return MOSQ_ERR_PROTOCOL;
+			}
+		}else{
+			if(reason_code != MQTT_RC_SUCCESS
+					&& reason_code != MQTT_RC_PACKET_ID_NOT_FOUND
+					){
+
+				return MOSQ_ERR_PROTOCOL;
+			}
+		}
+	}
+	if(mosq->in_packet.pos < mosq->in_packet.remaining_length){
+#ifdef WITH_BROKER
+		mosquitto_property_free_all(&properties);
+#endif
+		return MOSQ_ERR_MALFORMED_PACKET;
 	}
 
 #ifdef WITH_BROKER
