@@ -4,12 +4,12 @@ Copyright (c) 2010-2020 Roger Light <roger@atchoo.org>
 All rights reserved. This program and the accompanying materials
 are made available under the terms of the Eclipse Public License 2.0
 and Eclipse Distribution License v1.0 which accompany this distribution.
- 
+
 The Eclipse Public License is available at
    https://www.eclipse.org/legal/epl-2.0/
 and the Eclipse Distribution License is available at
   http://www.eclipse.org/org/documents/edl-v10.php.
- 
+
 SPDX-License-Identifier: EPL-2.0 OR BSD-3-Clause
 
 Contributors:
@@ -190,10 +190,14 @@ struct mosquitto_msg_data{
 #ifdef WITH_BROKER
 	struct mosquitto_client_msg *inflight;
 	struct mosquitto_client_msg *queued;
-	long msg_bytes;
-	long msg_bytes12;
-	int msg_count;
-	int msg_count12;
+	long inflight_bytes;
+	long inflight_bytes12;
+	int inflight_count;
+	int inflight_count12;
+	long queued_bytes;
+	long queued_bytes12;
+	int queued_count;
+	int queued_count12;
 #else
 	struct mosquitto_message_all *inflight;
 	int queue_len;
@@ -281,7 +285,7 @@ struct mosquitto {
 	time_t session_expiry_time;
 	uint32_t session_expiry_interval;
 #ifdef WITH_BROKER
-	bool removed_from_by_id; /* True if removed from by_id hash */
+	bool in_by_id;
 	bool is_dropping;
 	bool is_bridge;
 	struct mosquitto__bridge *bridge;
